@@ -3,6 +3,7 @@ from . import objects as objects
 from . import requests as bot
 from .base import UserProxyModel, Constants, exceptions as exc
 from .context import ctx
+from .loader import logger
 from .run import run
 
-__all__ = ['on', 'objects', 'bot', 'UserProxyModel', 'Constants', 'ctx', 'run', 'exc']
+__all__ = ['on', 'objects', 'bot', 'UserProxyModel', 'Constants', 'ctx', 'run', 'exc', 'logger']
